
def _style_colorbar(fig, label):
    fig.update_traces(colorbar=dict(
        title=dict(text=label, font=dict(size=10)),
        titleside='right',
        thickness=10,
    ))

def _dyn_y_label_size(plot_height, nr_labels):

    if nr_labels < 15:
        return 12
    elif nr_labels < 20:
        return 11
    elif nr_labels < 30:
        return 10
    else:
        return 9


from pyadlml.dataset._datasets.amsterdam import fetch_amsterdam
from pyadlml.dataset._datasets.aras import fetch_aras
from pyadlml.dataset._datasets.casas_aruba import fetch_casas_aruba
from pyadlml.dataset._datasets.mitlab import fetch_mitlab
from pyadlml.dataset._datasets.tuebingen_2019 import fetch_tuebingen_2019
from pyadlml.dataset._datasets.uci_adl_binary import fetch_uci_adl_binary
from pyadlml.dataset._datasets.kasteren_2010 import fetch_kasteren_2010

from pyadlml.dataset._datasets.homeassistant import (
    load_homeassistant, load_homeassistant_devices
)

from pyadlml.dataset._datasets.activity_assistant import load as load_act_assist

from pyadlml.dataset.io import (
    set_data_home,
    get_data_home,
    load,
    dump,
    clear_data_home,
)

from pyadlml.dataset import matplotlib, plotly, io, util


from pyadlml.constants import DEVICE, ACTIVITY


class Data(object):
    def __init__(self, activities=None, devices=None, activity_list=None, device_list=None):

        self.df_devices = devices

        if device_list is None:
            self.lst_devices = devices[DEVICE].unique()

        if activities is not None:
            self.df_activities = activities
            if activity_list is None:
                self.lst_activities = activities[ACTIVITY].unique()
            else:
                self.lst_activities = activity_list
            self.act_dict = {"default": self.df_activities}
        else:
            self.act_dict = {}



    def set_activity_list(self, lst, name=None):
        """
        """
        if name is None or name == "default":
            setattr(self, "lst_activities", lst)
        else:
            setattr(self, "lst_activities_{}".format(name), lst)


    def set_activity_df(self, df, name=None):
        """
        """
        if name is None or name == "default":
            setattr(self, "df_activities", df)
            self.act_dict["default"] = df
        else:
            setattr(self, "df_activities_{}".format(name), df)
            self.act_dict[name] = df

    def set_activity_correction(self, lst, name=None):
        if name is None or name == "default":
            self.correction_activities = lst
        else:
            setattr(self, "correction_activities_{}".format(name), lst)

    def set_device_correction(self, corr_dts, corr_incons):
        self.correction_devices_duplicate_timestamps = corr_dts
        self.correction_devices_on_off_inconsistency = corr_incons

    def get_activity_dict(self) -> dict:
        return self.act_dict

    def set_device_df(self, df):
        self.df_devices = df